==> mlinsightlab-0.0.7.tar.gz: mlinsightlab-0.0.7/src/mlinsightlab/data_mgmt.py <==
# Helper functions to manage and interact with MLFlow models
from .MLILException import MLILException
from .endpoints import DATA_UPLOAD, DATA_DOWNLOAD, LIST_DATA, GET_VARIABLE, LIST_VARIABLES, SET_VARIABLE, DELETE_VARIABLE, GET_PREDICTIONS
from typing import Any
import pandas as pd
import requests
import base64
import json
import io


def _list_data(
    url: str,
    creds: dict,
    directory: str
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Lists all data avaialble to a user.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    directory: str
        Name of the directory you wish to view the contents of.
    """

    url = f"{url}/{LIST_DATA}"

    json_data = {
        'directory': directory
    }

    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _upload_data(
    url: str,
    creds: dict,
    file_path: str,
    file_name: str,
    overwrite: bool = False
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Uploads a file to the MLIL platform's data store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    file_path: str
        Path to the file to be uploaded to MLIL.
    file_name: str
        The name to give your file in the MLIL datastore.
    overwrite: bool
        Whether or not to overwrite the file, if a file of the same name
        already exists.
    """

    url = f"{url}/{DATA_UPLOAD}"

    with open(file_path, 'rb') as f:
        file_bytes = f.read()

    json_data = {
        'filename': file_name,
        'file_bytes': base64.b64encode(file_bytes).decode('utf-8'),
        'overwrite': overwrite
    }

    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _download_data(
    url: str,
    creds: dict,
    file_name: str,
    output_file_name: str
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Downloads a file from the MLIL platform's data store as a byte string.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    file_name: str
        The name of the file to download.
    output_file_name: str
        The output name of the file to write to
    """

    url = f"{url}/{DATA_DOWNLOAD}"

    # TODO: Rewrite all of the below logic. Can be simplified
    json_data = {
        'filename': file_name
    }

    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))

    decoded_content = base64.b64decode(resp.content.decode('utf-8'))
    with open(output_file_name, 'wb') as f:
        f.write(decoded_content)


def _get_variable(
    url: str,
    creds: dict,
    variable_name: str
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Retrieve a variable from the MLIL variable store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    variable_name: str
        The name of the variable to access.
    """

    url = f"{url}/{GET_VARIABLE}/{variable_name}"

    with requests.Session() as sess:
        resp = sess.get(
            url,
            auth=(creds['username'], creds['key'])
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _list_variables(
    url: str,
    creds: dict
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Lists all variables associated with a user.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    """

    url = f"{url}/{LIST_VARIABLES}"

    with requests.Session() as sess:
        resp = sess.get(
            url,
            auth=(creds['username'], creds['key'])
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _set_variable(
    url: str,
    creds: dict,
    variable_name: str,
    value: Any,
    overwrite: bool = False
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Creates a variable within the MLIL variable store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    variable_name: str
        The name of the variable to set.
    overwrite: bool = False
        Whether to overwrite any variables that currently exist in MLIL and have the same name.
    value: Any
        Your variable. Can be of type string | integer | number | boolean | object | array<any>.
    """

    url = f"{url}/{SET_VARIABLE}"

    json_data = {
        'variable_name': variable_name,
        'value': value,
        'overwrite': overwrite
    }

    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _delete_variable(
    url: str,
    creds: dict,
    variable_name: str
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Removes a variable from the MLIL variable store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    variable_name: str
        The name of the variable to delete.
    """

    url = f"{url}/{DELETE_VARIABLE}/{variable_name}"

    with requests.Session() as sess:
        resp = sess.delete(
            url,
            auth=(creds['username'], creds['key'])
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _get_predictions(
        url: str,
        creds: dict,
        model_name: str,
        model_flavor: str,
        model_version_or_alias: str | int
):
    """
    NOT MEANT TO BE CALLED BY THE END USER

    Gets predictions that a model has made

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys "username" and "key", and associated values.
    model_name: str
        The name of the model to get predictions from
    model_flavor: str
        The flavor of the model to get predictions from
    model_version: str | int
        The version of the model to get predictions from
    """
    url = f'{
        url}/{GET_PREDICTIONS}/{model_name}/{model_flavor}/{model_version_or_alias}'

    with requests.Session() as sess:
        resp = sess.get(
            url,
            auth=(creds['username'], creds['key'])
        )

    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp

==> mlinsightlab-0.0.15.tar.gz: mlinsightlab-0.0.15/src/mlinsightlab/data_mgmt.py <==
# Helper functions to manage and interact with data

from .MLILException import MLILException
from .endpoints import DATA_UPLOAD, DATA_DOWNLOAD, LIST_DATA, GET_VARIABLE, LIST_VARIABLES, SET_VARIABLE, DELETE_VARIABLE, GET_PREDICTIONS, LIST_PREDICTIONS_MODELS
from typing import Any
import requests
import base64


def _list_data(
    url: str,
    creds: dict,
    directory: str
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Lists all data avaialble to a user.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    directory: str
        Name of the directory you wish to view the contents of in the `/data` directory on the platform.
    '''

    # Format the URL
    url = f'{url}/{LIST_DATA}'

    # Set up the JSON payload
    json_data = {
        'directory': directory
    }

    # Make the request to the system
    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    # Return either the response itself or raise an error if the request was not successful
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _upload_data(
    url: str,
    creds: dict,
    file_path: str,
    file_name: str,
    overwrite: bool = False
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Uploads a file to the MLIL platform's data store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    file_path: str
        Path to the file to be uploaded to MLIL.
    file_name: str
        The name to give your file in the MLIL datastore.
    overwrite: bool
        Whether or not to overwrite the file, if a file of the same name
        already exists.
    '''

    # Format the URL
    url = f'{url}/{DATA_UPLOAD}'

    # Read the bytes of the file
    with open(file_path, 'rb') as f:
        file_bytes = f.read()

    # Format the JSON payload
    json_data = {
        'filename': file_name,
        # <- encode the bytes so they transfer as a string
        'file_bytes': base64.b64encode(file_bytes).decode('utf-8'),
        'overwrite': overwrite
    }

    # Make the request
    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    # Return either the response itself or raise an error if the request was not successful
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _download_data(
    url: str,
    creds: dict,
    file_name: str,
    output_file_name: str
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Downloads a file from the MLIL platform's data store as a byte string.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    file_name: str
        The name of the file to download.
    output_file_name: str
        The output name of the file to write to

    Returns
    -------
    success: bool
        If successful, returns True
    '''

    # Format the URL
    url = f'{url}/{DATA_DOWNLOAD}'

    # Format the JSON payload
    json_data = {
        'filename': file_name
    }

    # Make the request
    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    # If the request was not successful, raise an Exception
    if not resp.ok:
        raise MLILException(str(resp.json()))

    # Write the file to the specified location
    with open(output_file_name, 'wb') as f:
        f.write(
            base64.b64decode(resp.content.decode('utf-8'))
        )

    # Return True for success
    return True


def _get_variable(
    url: str,
    creds: dict,
    variable_name: str
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Retrieve a variable from the MLIL variable store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    variable_name: str
        The name of the variable to access.
    '''

    # Format the URL
    url = f'{url}/{GET_VARIABLE}/{variable_name}'

    # Make the request
    with requests.Session() as sess:
        resp = sess.get(
            url,
            auth=(creds['username'], creds['key'])
        )

    # If the request was not successful, raise exception, else return the response
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _list_variables(
    url: str,
    creds: dict
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Lists all variables associated with a user.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    '''

    # Format the URL
    url = f'{url}/{LIST_VARIABLES}'

    # Make the request
    with requests.Session() as sess:
        resp = sess.get(
            url,
            auth=(creds['username'], creds['key'])
        )

    # If the request was not successful, raise appropriate exception, else return the response
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _set_variable(
    url: str,
    creds: dict,
    variable_name: str,
    value: Any,
    overwrite: bool = False
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Creates a variable within the MLIL variable store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    variable_name: str
        The name of the variable to set.
    overwrite: bool = False
        Whether to overwrite any variables that currently exist in MLIL and have the same name.
    value: Any
        Your variable. Can be of type string | integer | number | boolean | object | array<any>.
    '''

    # Format the URL
    url = f'{url}/{SET_VARIABLE}'

    # Format the JSON payload
    json_data = {
        'variable_name': variable_name,
        'value': value,
        'overwrite': overwrite
    }

    # Make the request to the platform
    with requests.Session() as sess:
        resp = sess.post(
            url,
            auth=(creds['username'], creds['key']),
            json=json_data
        )

    # If the request is not successful, raise an appropriate respone, else return the response
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _delete_variable(
    url: str,
    creds: dict,
    variable_name: str
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Removes a variable from the MLIL variable store.
    Called within the MLILClient class.

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    variable_name: str
        The name of the variable to delete.
    '''

    # Format the URL
    url = f'{url}/{DELETE_VARIABLE}/{variable_name}'

    # Make the request to the platform
    with requests.Session() as sess:
        resp = sess.delete(
            url,
            auth=(creds['username'], creds['key'])
        )

    # Return the response or raise an exception as necessary
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _get_predictions(
        url: str,
        creds: dict,
        model_name: str,
        model_flavor: str,
        model_version_or_alias: str | int
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Gets predictions that a model has made

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform.
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    model_name: str
        The name of the model to get predictions from
    model_flavor: str
        The flavor of the model to get predictions from
    model_version: str | int
        The version of the model to get predictions from
    '''

    # Format the URL
    url = f'{url}/{GET_PREDICTIONS}/{model_name}/{model_flavor}/{model_version_or_alias}'

    # Make the request to the platform
    with requests.Session() as sess:
        resp = sess.get(
            url,
            auth=(creds['username'], creds['key'])
        )

    # Raise an exception or return the successful response
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp


def _list_prediction_models(
        url: str,
        creds: dict
):
    '''
    NOT MEANT TO BE CALLED BY THE END USER

    Lists models that have stored predictions

    Parameters
    ----------
    url: str
        String containing the URL of your deployment of the platform
    creds: dict
        Dictionary that must contain keys 'username' and 'key', and associated values.
    '''

    # Format the URL
    url = f'{url}/{LIST_PREDICTIONS_MODELS}'

    # Make the request to the platform
    with requests.Session() as sess:
        resp = sess.get(
            url,
            auth=(creds['username'], creds['key'])
        )

    # Raise an exception or return the successful response as necessary
    if not resp.ok:
        raise MLILException(str(resp.json()))
    return resp
